# This is a stand-alone version of minGPT by Andrej Karpathy as a single Python module

## Based on minGPT sorce code as it appears on Aug 25, 2020

## https://github.com/karpathy/minGPT

***

### Project Los Angeles
### Tegridy Code
